@@ -3,13 +3,13 @@ use strict;
 use base qw(Exporter);
 use 5.006;
 our @EXPORT_OK = qw(tlds tld_exists);
-our $VERSION = '1.70';
+our $VERSION = '1.71';
 
 use warnings;
 use Carp;
 use Storable qw ( dclone );
 
-use constant TLD_TYPES => qw ( new_open new_restricted gtld_open gtld_restricted cc ccidn );
+use constant TLD_TYPES => qw ( new_open new_restricted gtld_open gtld_restricted gtld_new cc ccidn );
 
 =head1 NAME
 
@@ -375,7 +375,185 @@ my %tld_profile = (
     'xn--xkc2dl3a5ee0h' => q{National Internet Exchange of India},
     'xn--yfro4i67o' => q{Singapore Network Information Centre (SGNIC) Pte Ltd},
     'xn--ygbi2ammx' => q{Ministry of Telecom &amp; Information Technology (MTIT)},
-    'xn--zckzah' => q{Internet Assigned Numbers Authority}
+    'xn--zckzah' => q{Internet Assigned Numbers Authority},
+    'xn--3bst00m' => q{Eagle Horizon Limited},
+    'xn--3ds443g' => q{TLD REGISTRY LIMITED},
+    'xn--55qw42g' => q{China Organizational Name Administration Center},
+    'xn--55qx5d' => q{Computer Network Information Center of Chinese Academy of Sciences （China Internet Network Information Center）},
+    'xn--6frz82g' => q{Afilias Limited},
+    'xn--6qq986b3xl' => q{Tycoon Treasure Limited},
+    'xn--80asehdb' => q{CORE Association},
+    'xn--80aswg' => q{CORE Association},
+    'xn--c1avg' => q{Public Interest Registry},
+    'xn--cg4bki' => q{SAMSUNG SDS CO., LTD},
+    'xn--d1acj3b' => q{The Foundation for Network Initiatives “The Smart Internet”},
+    'xn--fiq228c5hs' => q{TLD REGISTRY LIMITED},
+    'xn--fiq64b' => q{CITIC Group Corporation},
+    'xn--i1b6b1a6a2e' => q{Public Interest Registry},
+    'xn--io0a7i' => q{Computer Network Information Center of Chinese Academy of Sciences （China Internet Network Information Center）},
+    'xn--mgbab2bd' => q{CORE Association},
+    'xn--ngbc5azd' => q{International Domain Registry Pty. Ltd.},
+    'xn--nqv7f' => q{Public Interest Registry},
+    'xn--nqv7fs00ema' => q{Public Interest Registry},
+    'xn--q9jyb4c' => q{Charleston Road Registry Inc.},
+    'xn--rhqv96g' => q{Stable Tone Limited},
+    'xn--unup4y' => q{Spring Fields, LLC},
+    'xn--zfr164b' => q{China Organizational Name Administration Center}
+  },
+  gtld_new => {
+    'academy' => q{Half Oaks, LLC},
+    'actor' => q{United TLD Holdco Ltd.},
+    'agency' => q{Steel Falls, LLC},
+    'axa' => q{AXA SA},
+    'bar' => q{Punto 2012 Sociedad Anonima Promotora de Inversion de Capital Variable},
+    'bargains' => q{Half Hallow, LLC},
+    'berlin' => q{dotBERLIN GmbH &amp; Co. KG},
+    'best' => q{BestTLD Pty Ltd},
+    'bid' => q{dot Bid Limited},
+    'bike' => q{Grand Hollow, LLC},
+    'blue' => q{Afilias Limited},
+    'boutique' => q{Over Galley, LLC},
+    'build' => q{Plan Bee LLC},
+    'builders' => q{Atomic Madison, LLC},
+    'buzz' => q{DOTSTRATEGY CO.},
+    'cab' => q{Half Sunset, LLC},
+    'camera' => q{Atomic Maple, LLC},
+    'camp' => q{Delta Dynamite, LLC},
+    'cards' => q{Foggy Hollow, LLC},
+    'careers' => q{Wild Corner, LLC},
+    'catering' => q{New Falls. LLC},
+    'center' => q{Tin Mill, LLC},
+    'ceo' => q{CEOTLD Pty Ltd},
+    'cheap' => q{Sand Cover, LLC},
+    'christmas' => q{Uniregistry, Corp.},
+    'cleaning' => q{Fox Shadow, LLC},
+    'clothing' => q{Steel Lake, LLC},
+    'club' => q{.CLUB DOMAINS, LLC},
+    'codes' => q{Puff Willow, LLC},
+    'coffee' => q{Trixy Cover, LLC},
+    'cologne' => q{NetCologne Gesellschaft für Telekommunikation mbH},
+    'community' => q{Fox Orchard, LLC},
+    'company' => q{Silver Avenue, LLC},
+    'computer' => q{Pine Mill, LLC},
+    'construction' => q{Fox Dynamite, LLC},
+    'contractors' => q{Magic Woods, LLC},
+    'cool' => q{Koko Lake, LLC},
+    'cruises' => q{Spring Way, LLC},
+    'dance' => q{United TLD Holdco Ltd.},
+    'dating' => q{Pine Fest, LLC},
+    'democrat' => q{United TLD Holdco Ltd.},
+    'diamonds' => q{John Edge, LLC},
+    'directory' => q{Extra Madison, LLC},
+    'domains' => q{Sugar Cross, LLC},
+    'education' => q{Brice Way, LLC},
+    'email' => q{Spring Madison, LLC},
+    'enterprises' => q{Snow Oaks, LLC},
+    'equipment' => q{Corn Station, LLC},
+    'estate' => q{Trixy Park, LLC},
+    'events' => q{Pioneer Maple, LLC},
+    'expert' => q{Magic Pass, LLC},
+    'exposed' => q{Victor Beach, LLC},
+    'farm' => q{Just Maple, LLC},
+    'fish' => q{Fox Woods, LLC},
+    'flights' => q{Fox Station, LLC},
+    'florist' => q{Half Cypress, LLC},
+    'foundation' => q{John Dale, LLC},
+    'futbol' => q{United TLD Holdco, Ltd.},
+    'gallery' => q{Sugar House, LLC},
+    'gift' => q{Uniregistry, Corp.},
+    'glass' => q{Black Cover, LLC},
+    'graphics' => q{Over Madison, LLC},
+    'guitars' => q{Uniregistry, Corp.},
+    'guru' => q{Pioneer Cypress, LLC},
+    'holdings' => q{John Madison, LLC},
+    'holiday' => q{Goose Woods, LLC},
+    'house' => q{Sugar Park, LLC},
+    'immobilien' => q{United TLD Holdco Ltd.},
+    'industries' => q{Outer House, LLC},
+    'institute' => q{Outer Maple, LLC},
+    'international' => q{Wild Way, LLC},
+    'jetzt' => q{New TLD Company AB},
+    'kaufen' => q{United TLD Holdco Ltd.},
+    'kim' => q{Afilias Limited},
+    'kitchen' => q{Just Goodbye, LLC},
+    'kiwi' => q{DOT KIWI LIMITED},
+    'koeln' => q{NetCologne Gesellschaft für Telekommunikation mbH},
+    'kred' => q{KredTLD Pty Ltd},
+    'land' => q{Pine Moon, LLC},
+    'lighting' => q{John McCook, LLC},
+    'limo' => q{Hidden Frostbite, LLC},
+    'link' => q{Uniregistry, Corp.},
+    'luxury' => q{Luxury Partners LLC},
+    'management' => q{John Goodbye, LLC},
+    'mango' => q{PUNTO FA S.L.},
+    'marketing' => q{Fern Pass, LLC},
+    'menu' => q{Wedding TLD2, LLC},
+    'moda' => q{United TLD Holdco Ltd.},
+    'monash' => q{Monash University},
+    'nagoya' => q{GMO Registry, Inc.},
+    'neustar' => q{NeuStar, Inc.},
+    'ninja' => q{United TLD Holdco Ltd.},
+    'okinawa' => q{BusinessRalliart inc.},
+    'onl' => q{I-REGISTRY Ltd., Niederlassung Deutschland},
+    'partners' => q{Magic Glen, LLC},
+    'parts' => q{Sea Goodbye, LLC},
+    'photo' => q{Uniregistry, Corp.},
+    'photography' => q{Sugar Glen, LLC},
+    'photos' => q{Sea Corner, LLC},
+    'pics' => q{Uniregistry, Corp.},
+    'pink' => q{Afilias Limited},
+    'plumbing' => q{Spring Tigers, LLC},
+    'productions' => q{Magic Birch, LLC},
+    'properties' => q{Big Pass, LLC},
+    'pub' => q{United TLD Holdco Ltd.},
+    'qpon' => q{dotCOOL, Inc.},
+    'recipes' => q{Grand Island, LLC},
+    'red' => q{Afilias Limited},
+    'rentals' => q{Big Hollow,LLC},
+    'repair' => q{Lone Sunset, LLC},
+    'report' => q{Binky Glen, LLC},
+    'reviews' => q{United TLD Holdco, Ltd.},
+    'rich' => q{I-REGISTRY Ltd., Niederlassung Deutschland},
+    'ruhr' => q{regiodot GmbH &amp; Co. KG},
+    'sexy' => q{Uniregistry, Corp.},
+    'shiksha' => q{Afilias Limited},
+    'shoes' => q{Binky Galley, LLC},
+    'singles' => q{Fern Madison, LLC},
+    'social' => q{United TLD Holdco Ltd.},
+    'solar' => q{Ruby Town, LLC},
+    'solutions' => q{Silver Cover, LLC},
+    'supplies' => q{Atomic Fields, LLC},
+    'supply' => q{Half Falls, LLC},
+    'support' => q{Grand Orchard, LLC},
+    'systems' => q{Dash Cypress, LLC},
+    'tattoo' => q{Uniregistry, Corp.},
+    'technology' => q{Auburn Falls, LLC},
+    'tienda' => q{Victor Manor, LLC},
+    'tips' => q{Corn Willow, LLC},
+    'today' => q{Pearl Woods, LLC},
+    'tokyo' => q{GMO Registry, Inc.},
+    'tools' => q{Pioneer North, LLC},
+    'trade' => q{Elite Registry Limited},
+    'training' => q{Wild Willow, LLC},
+    'uno' => q{Dot Latin LLC},
+    'vacations' => q{Atomic Tigers, LLC},
+    'ventures' => q{Binky Lake, LLC},
+    'viajes' => q{Black Madison, LLC},
+    'villas' => q{New Sky, LLC},
+    'vision' => q{Koko Station, LLC},
+    'vote' => q{Monolith Registry LLC},
+    'voting' => q{Valuetainment Corp.},
+    'voto' => q{Monolith Registry LLC},
+    'voyage' => q{Ruby House, LLC},
+    'wang' => q{Zodiac Leo Limited},
+    'watch' => q{Sand Shadow, LLC},
+    'webcam' => q{dot Webcam Limited},
+    'wed' => q{Atgron, Inc.},
+    'wien' => q{punkt.wien GmbH},
+    'wiki' => q{Top Level Design, LLC},
+    'works' => q{Little Dynamite, LLC},
+    'xyz' => q{XYZ.COM LLC},
+    'zone' => q{Outer Falls, LLC}
   }
 );
 
@@ -415,6 +593,7 @@ sub check_type {
     ccidn              - internationalized country code top-level domain 
     gtld_open          - generic domains that anyone can register
     gtld_restricted    - generic restricted registration domains
+    gtld_new           - new gTLDs
     new_open           - recently added generic domains
     new_restricted     - new restricted registration domains
 
@@ -451,7 +630,7 @@ sub tld_exists {
 
 =head1 COPYRIGHT
 
-  Copyright (c) 2003-2005 Alex Pavlovic, all rights reserved.  This program
+  Copyright (c) 2003-2014 Alex Pavlovic, all rights reserved.  This program
   is free software; you can redistribute it and/or modify it under the same terms
   as Perl itself.
 
